

function minimal_MD()

     %close all
     figure

     %Paramters
     rc = 2.5; %2^(1/6);

     %Domain extents
     domain_min = -1.5;
     domain_max =  1.5;

     %Initial values for two molecules
     ri = [-0.7, 0.5];    vi = [0.5, 0.5];
     rj = [0.7, 0.75];     vj = [-0.5, 0.0];

     a = 0;
     U = 0;

     Nsteps = 400;
     delta_t = 0.005;
     %Verlet leapfrog or whatever
     for n = 1:Nsteps
         
         %Calculate forces
         [a,U] = Force_calculation(ri,rj,rc);
         
         %Update molecular positions using leapfrog
         [ri,rj,vi,vj] = Leapfrog_int(ri,rj,vi,vj,a,delta_t);

         plot(ri(1),ri(2),'ro','MarkerFaceColor','k')
         hold all
         plot(rj(1),rj(2),'bo','MarkerFaceColor','k')
         hold off
         axis([domain_min domain_max -0.1 1.1])
         pause(0.01); 
         %drawnow


         %Total energy
         K =  0.5*sum(  vi(1)^2 + vi(2)^2 ...
                      + vj(1)^2 + vj(2)^2);
         E = K + U;
         disp(["Momentum=", sum(vi+vj), "E_kin=", K, ...
               "E_pot=", U, "E_Total=", E])
         
     end
              
end

%Force calculation

function[a, U] = Force_calculation(ri,rj,rc)

     U_ij = @(rij) 4*(1./rij.^12 - 1./rij.^6) + 1;
     F_ij = @(rij) 48*(1./rij.^13 - 0.5./rij.^7);

     rij = ri - rj;
     magrij = sqrt(rij(1)^2 + rij(2)^2);
     if (magrij < rc)
         a = F_ij(magrij)*rij/magrij;
         U = 0.5*(U_ij(magrij) + U_ij(magrij));
     else
         a = 0;
         U = 0;
     end

return

end

%Update molecular positions using leapfrog
function[ri_tp1,rj_tp1,vi_tp1,vj_tp1] = Leapfrog_int(ri,rj,vi,vj,a,delta_t)
     vi_tp1 = vi + a*delta_t;
     ri_tp1 = ri + vi_tp1*delta_t;

     vj_tp1 = vj - a*delta_t;
     rj_tp1 = rj + vj_tp1*delta_t;

     return

end




